@@ -30,4 +30,15 @@ mcTrans.profileLadder <- function(object){
   if (!grepl("MACRAME", object$method)){stop("The input object must be the output of the MACRAME algorithm -- the function mcReserve().\n There is no underlying Markov Chain in PARALLAX or REACT algorithm -- the function parallelReserve().")}
 
   return(object$MarkovChain$transitionMatrix)
-}
\ No newline at end of file
+}
+
+#' @export
+mcTrans.mcSetup <- function(object){
+  ### no transition matrix applicable for incrExplor() function
+  if (!inherits(object, "mcSetup")){stop("The input object must be of class 'mcSetup' which is an output from the function incrExplor()")}
+  if (inherits(object, "mcSetup")){
+    message("There is no transition matrix being estimated with the 'incrExplor()' function")
+    message("(use the 'mcReserve()' function to get the estimated transition probabilities)")
+  }
+}
+
